@@ -6,11 +6,19 @@ class FuncInvokeError(EasyPushError):
     pass
 
 
-class BackendModuleError(EasyPushError):
+class InvalidTokenError(EasyPushError):
+    pass
+
+
+class BackendError(EasyPushError):
+    pass
+
+
+class BackendModuleError(BackendError):
     """ backend module is empty. """
 
 
-class InvalidBackendConfigError(EasyPushError):
+class InvalidBackendConfigError(BackendError):
     pass
 
 
@@ -18,6 +26,10 @@ class MessageTypeError(EasyPushError):
     pass
 
 
+class MessagePlatformError(EasyPushError):
+    pass
+
+
 class MessageBodyFieldError(EasyPushError):
     pass
 
@@ -28,3 +40,11 @@ class NotExistMessageBodyMethod(EasyPushError):
 
 class ExceedContentMaxSizeError(EasyPushError):
     pass
+
+
+class CeleryAppNotFoundError(EasyPushError):
+    pass
+
+
+class TokenError(EasyPushError):
+    pass
