@@ -1,12 +1,14 @@
 from copy import copy
+
+import yaml
 from django.conf import settings
 
 DEFAULTS = {
     "log_path": "",
 
     "default": {
-        "BACKEND": "easypush.backends.ding_talk.DingTalkClient",
         # dingtalk
+        "BACKEND": "easypush.backends.ding_talk.DingTalkClient",
         "CORP_ID": None,
         "AGENT_ID": None,
         "APP_KEY": None,
@@ -17,6 +19,14 @@ DEFAULTS = {
 DEFAULT_EASYPUSH_ALIAS = 'default'
 
 
+class ConfigYaml:
+    def __init__(self, filename):
+        self.filename = filename
+
+    def load(self, alias):
+        pass
+
+
 class Singleton(type, metaclass=object):
     def __init__(cls, name, bases, d):
         super(Singleton, cls).__init__(name, bases, d)
